@@ -82,6 +82,7 @@ def run_command_as_user(command: str, user: str, env_vars: dict):
     Run a command as a specific user with the given environment variables.
     """
     env_vars.update({"PATH": get_env_var("PATH")})
+    env_vars.update({"PYTHONPATH": get_env_var("PYTHONPATH")})
     env_vars_str = " ".join(f"{key}='{value}'" for key, value in env_vars.items())
     full_command = f"sudo -u {user} {env_vars_str} {command}"
     logger.debug(f"Running command: {full_command}")
@@ -89,12 +90,12 @@ def run_command_as_user(command: str, user: str, env_vars: dict):
 
 
 def main():
+    logger.info(f"Env inside datatailr_run.py: {os.environ}")
     user, _ = create_user_and_group()
     job_type = get_env_var("DATATAILR_JOB_TYPE")
 
     job_name = get_env_var("DATATAILR_JOB_NAME")
     job_id = get_env_var("DATATAILR_JOB_ID")
-    entrypoint = get_env_var("DATATAILR_ENTRYPOINT")
 
     if job_type == "batch":
         run_id = get_env_var("DATATAILR_BATCH_RUN_ID")
@@ -102,6 +103,7 @@ def main():
         job_argument_mapping = get_env_var(
             "DATATAILR_JOB_ARGUMENT_MAPPING", encode_json({})
         )
+        entrypoint = get_env_var("DATATAILR_BATCH_ENTRYPOINT")
         env = {
             "DATATAILR_BATCH_RUN_ID": run_id,
             "DATATAILR_BATCH_ID": batch_id,
@@ -111,13 +113,17 @@ def main():
         }
         run_command_as_user("datatailr_run_batch", user, env)
     elif job_type == "service":
+        port = get_env_var("DATATAILR_SERVICE_PORT")
+        entrypoint = get_env_var("DATATAILR_ENTRYPOINT")
         env = {
             "DATATAILR_JOB_NAME": job_name,
             "DATATAILR_JOB_ID": job_id,
             "DATATAILR_ENTRYPOINT": entrypoint,
+            "DATATAILR_SERVICE_PORT": port,
         }
         run_command_as_user("datatailr_run_service", user, env)
     elif job_type == "app":
+        entrypoint = get_env_var("DATATAILR_ENTRYPOINT")
         env = {
             "DATATAILR_JOB_NAME": job_name,
             "DATATAILR_JOB_ID": job_id,
@@ -125,10 +131,13 @@ def main():
         }
         run_command_as_user("datatailr_run_app", user, env)
     elif job_type == "excel":
+        host = get_env_var("DATATAILR_HOST")
+        entrypoint = get_env_var("DATATAILR_ENTRYPOINT")
         env = {
             "DATATAILR_JOB_NAME": job_name,
             "DATATAILR_JOB_ID": job_id,
             "DATATAILR_ENTRYPOINT": entrypoint,
+            "DATATAILR_HOST": host,
         }
         run_command_as_user("datatailr_run_excel", user, env)
     elif job_type == "IDE":
